Package: qcmetrics
Type: Package
Title: A Framework for Quality Control
Version: 1.48.0
Authors@R: person(given = "Laurent", family = "Gatto",
                  email = "laurent.gatto@uclouvain.be",
                  role = c("aut","cre"))
Description: The package provides a framework for generic quality
             control of data. It permits to create, manage and
             visualise individual or sets of quality control metrics
             and generate quality control reports in various formats.
Depends: R (>= 3.3)
Imports: Biobase, methods, knitr, tools, xtable, pander, S4Vectors
Suggests: affy, MSnbase, ggplot2, lattice, mzR, BiocStyle, rmarkdown,
        markdown
License: GPL-2
URL: http://lgatto.github.io/qcmetrics/articles/qcmetrics.html
BugReports: https://github.com/lgatto/qcmetrics/issues
biocViews: ImmunoOncology, Software, QualityControl, Proteomics,
        Microarray, MassSpectrometry, Visualization, ReportWriting
VignetteBuilder: knitr
RoxygenNote: 6.1.0
git_url: https://git.bioconductor.org/packages/qcmetrics
git_branch: RELEASE_3_22
git_last_commit: 7058a53
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:52:25 UTC; biocbuild
Author: Laurent Gatto [aut, cre]
Maintainer: Laurent Gatto <laurent.gatto@uclouvain.be>
